@@ -8,6 +8,5 @@ __credits__ = """
 Prof. Dr. Jan Baumbach, Chair of Computational Systems Biology (https://www.cosy.bio/), University of Hamburg ; 
 Dr. Markus List, Head of the Research Group Big Data in BioMedicine (https://biomedical-big-data.de/), Technical University of Munich"""
 
-from caddiepy import api
-from caddiepy.task import Task
-from caddiepy.examples import GDSC_study
\ No newline at end of file
+from .task import Task
+from .examples import GDSC_study
\ No newline at end of file
