@@ -39,6 +39,7 @@ def get_task(token, interval=1):
         endpoint_task = f'{settings.DOMAIN}{settings.Endpoints.TASK}?token={token}'
 
         response_task = requests.get(endpoint_task).json()
+        print(response_task)
         if response_task['info']['failed']:
             logger.warning(f"task {token} failed due to {response_task['info']['status']}")
             return None
@@ -51,6 +52,6 @@ def get_task(token, interval=1):
         if response.status_code != 200:
             logger.warning(f'Failed getting result for {token}')
             continue
-        logger.debug('Got results for', token)
+        logger.debug(f'Got results for {token}')
         return response.json()
 
