@@ -2,7 +2,7 @@ from enum import Enum
 import json
 
 
-PATH_SOTRAGE = '.temp'
+PATH_SOTRAGE = 'storage'
 
 class Algorithm(str, Enum):
     TRUSTRANK = 'trustrank'
